@@ -4,14 +4,14 @@ use Moose::Role;
 
 with 'MooseX::Log::Log4perl';
 
-our $VERSION = '0.31';
+our $VERSION = '0.40';
 
-sub log_fatal {	my $self = shift; $self->logger->fatal(@_); }
-sub log_error {	my $self = shift; $self->logger->error(@_); }
-sub log_warn  {	my $self = shift; $self->logger->warn(@_); }
-sub log_info  {	my $self = shift; $self->logger->info(@_); }
-sub log_debug {	my $self = shift; $self->logger->debug(@_); }
-sub log_trace {	my $self = shift; $self->logger->trace(@_); }
+sub log_fatal { local $Log::Log4perl::caller_depth += 1; shift->logger->fatal(@_); }
+sub log_error { local $Log::Log4perl::caller_depth += 1; shift->logger->error(@_); }
+sub log_warn  { local $Log::Log4perl::caller_depth += 1; shift->logger->warn(@_); }
+sub log_info  { local $Log::Log4perl::caller_depth += 1; shift->logger->info(@_); }
+sub log_debug { local $Log::Log4perl::caller_depth += 1; shift->logger->debug(@_); }
+sub log_trace { local $Log::Log4perl::caller_depth += 1; shift->logger->trace(@_); }
 
 1;
 
@@ -39,20 +39,28 @@ This document describes MooseX::Log::Log4perl::Easy version 0.31
 
  sub foo {
    my ($self) = @_;
-   $self->log_debug("started bar");    ### logs with default class catergory "MyApp"
-   $self->log_info('bar');  ### logs an info message
+   $self->log_debug("started bar");            ### logs with default class catergory "MyApp"
+   $self->log_info('bar');                     ### logs an info message
    $self->log('AlsoPossible')->fatal("croak"); ### log
  }
 
 =head1 DESCRIPTION
 
 The Easy logging role based on the L<MooseX::Log::Log4perl> logging role for Moose directly adds the
-logmethods for all available levels to your clas instance. Hence it is possible to use
+logmethods for all available levels to your class instance. Hence it is possible to use
 
   $self->log_info("blabla");
 
 without having to access a seperate log attribute as in MooseX::Log::Log4perl;
 
+In case your app grows and you need more of the super-cow powers of Log4perl or simply don't want the additional 
+methodes to clutter up your class you can simply replace all code C<< $self->log_LEVEL >> with 
+C<< $self->log->LEVEL >>.
+
+You can use the following regex substitution to accomplish that:
+
+  s/log(_(trace|debug|info|warn|error|fatal))/log->$2/g
+
 =head1 ACCESSORS
 
 =head2 logger
@@ -117,9 +125,11 @@ Roland Lammel C<< <lammel@cpan.org> >>
 
 Inspired by suggestions by Michael Schilli C<< <m@perlmeister.com> >>
 
+Contributions from Tim Bunce C<< <TIMB@cpan.org> >>
+
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2008, Roland Lammel C<< <lammel@cpan.org> >>. Some rights reserved.
+Copyright (c) 2008-2009, Roland Lammel C<< <lammel@cpan.org> >>, http://www.quikit.at. Some rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
